from _typeshed import Incomplete

class DBRPGet:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, content: Incomplete | None = None) -> None: ...
    @property
    def content(self): ...
    @content.setter
    def content(self, content) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
